![](http://pinaxproject.com/pinax-design/patches/pinax-stripe.svg)

# Pinax Stripe (Light)

[![](https://img.shields.io/pypi/v/pinax-stripe-light.svg)](https://pypi.python.org/pypi/pinax-stripe-light/)
[![](https://img.shields.io/badge/license-MIT-blue.svg)](https://pypi.python.org/pypi/pinax-stripe-light/)

[![Codecov](https://img.shields.io/codecov/c/github/pinax/pinax-stripe-light.svg)](https://codecov.io/gh/pinax/pinax-stripe-light)
[![Build](https://github.com/pinax/pinax-stripe-light/actions/workflows/ci.yaml/badge.svg)](https://github.com/pinax/pinax-stripe-light/actions)
![](https://img.shields.io/github/contributors/pinax/pinax-stripe-light.svg)
![](https://img.shields.io/github/issues-pr/pinax/pinax-stripe-light.svg)
![](https://img.shields.io/github/issues-pr-closed/pinax/pinax-stripe-light.svg)

[![](http://slack.pinaxproject.com/badge.svg)](http://slack.pinaxproject.com/)

This app was formerly called `django-stripe-payments` and has been renamed to
avoid namespace collisions and to have more consistency with Pinax.  It has once
[more been renamed](https://github.com/pinax/pinax-stripe-light/discussions/644)
to `pinax-stripe-light` (package name, though it retains the `pinax.stripe.*`
Python namespace).

## Pinax

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps and starter project templates.
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.


## pinax-stripe-light

`pinax-stripe-light` is a Django app for integrating Stripe webhooks into your
project.  It also includes from lightweight utilities like template tags to make
working with Stripe a bit easier.


## Contribute

See [this blog post](http://blog.pinaxproject.com/2016/02/26/recap-february-pinax-hangout/) including a video, or our [How to Contribute](http://pinaxproject.com/pinax/how_to_contribute/) section for an overview on how contributing to Pinax works. For concrete contribution ideas, please see our [Ways to Contribute/What We Need Help With](http://pinaxproject.com/pinax/ways_to_contribute/) section.

In case of any questions we recommend you [join our Pinax Slack team](http://slack.pinaxproject.com) and ping us there instead of creating an issue on GitHub. Creating issues on GitHub is of course also valid but we are usually able to help you faster if you ping us in Slack.


## Code of Conduct

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found [here](http://pinaxproject.com/pinax/code_of_conduct/). We ask you to treat everyone as a smart human programmer that shares an interest in Python, Django, and Pinax with you.


## Pinax Project Blog and Twitter

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our [blog]( http://blog.pinaxproject.com).
